# RLSchool

RLSchool是一个强化学习模拟环境合集。

# 环境

- [LiftSim][liftsim]：电梯调度模拟

[liftsim]: https://github.com/PaddlePaddle/RLSchool/tree/master/rlschool/liftsim

- [Quadrotor][quadrotor]: 3D四轴飞行器

[quadrotor]: https://github.com/PaddlePaddle/RLSchool/tree/master/rlschool/quadrotor
